@@ -10,13 +10,13 @@ client.h
 #include <string.h>
 
 
-#define VERSION "v0.0.1b"
+#define VERSION "v0.0.2b"
 
 #define CMDBUFF_LEN 1024 /* tamanho do buffer da linha de comando */
 
 char cmdbuff[CMDBUFF_LEN]; /* buffer da linha de comando */
 
-char *prompt = "tuxbuzz> "; /* nosso prompt */
+char *prompt = "tuxbuzz-"VERSION"> "; /* nosso prompt */
 
 /* o banner */
 char *banner = "\n\n************************************************************************" 
