@@ -1,6 +1,6 @@
 /*************************************************************************
-TuXBuZZ - Server bY DoC#include
-requests.h - processa as requests do cliente
+TuXBuZZ - bY DoC#include
+requests.h 
 **************************************************************************/
 
 #ifndef REQUESTS_H
@@ -19,23 +19,18 @@ requests.h - processa as requests do cliente
 #include <string.h> 
 #include <pwd.h>
 
-struct package{
-	int size;
-	char data[1024];
-							};
-              
-             
 
-#define RQ_INFO 1
-#define RQ_GET 2
-#define RQ_DISCONNECT 3
-
-#define RQ_INFO_REMOTE "01"
-#define RQ_INFO_USER   "02"
+#include "tuxbuzzpackage.h"
+#include "messages.h"							
               
-int parse_requests(char *requeststring,int clientsock);
+int parse_requests(struct TuxbuzzPackage pack,int clientsock);
 int process_request_info(int clientsock,int flags);
 int process_request_get(int clientsock);
 int process_request_disconnect(int clientsock);
-              
+int process_request_ls(int clientsock); 
+int process_request_cd(int clientsock,struct TuxbuzzPackage tpack);
+int process_request_pwd(int clientsock);
+            
 #endif
+
+/* fim de requests.h */
