@@ -1,5 +1,5 @@
 /*************************************************************************
-TuXBuZZ - Server bY DoC#include
+TuXBuZZ - bY DoC#include
 server.h
 *************************************************************************/
 
@@ -19,26 +19,24 @@ server.h
 #include <string.h>
 #include <errno.h>
 #include <unistd.h>
+#include <signal.h>
 
-
+#include "tuxbuzzpackage.h"
+#include "messages.h"
+#include "zombiekiller.h"
 
 #define PORT 8081   /*porta padrao do servidor */
-#define BUFF_LEN 1024
 
-#define VERSION "0.0.1b"
 
-int parse_requests(char *requeststring,int clientsock);
-#define RQ_INFO 1
-#define RQ_GET 2
-#define RQ_DISCONNECT 3
+#define VERSION "v0.0.2b"
+
+
+/* fim de server.h */
+
+          
+
 
-#define TUXBUZZKEY "AaYuiYttRe45%)9)-_==+ttY"          
 
-char genbuff[1024];
 
-struct tuxbuzzack{
-uid_t serveruid;
-char tuxbuzzkey[25];
-};
 
 #endif
